Type Definition amq_protocol_types::generation::GenResult
source · [−]pub type GenResult<W> = Result<WriteContext<W>, GenError>;Expand description
Serialization types and traits Holds the result of serializing functions
The Ok case returns the Write used for writing, in the Err case an instance of
cookie_factory::GenError is returned.